% Auto-generated chapter 38 for tirmidhi
% Hadiths in this chapter: 51

\hadithdefcmd{tirmidhi}{2523}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّ فِي الْجَنَّةِ لَشَجَرَةً يَسِيرُ الرَّاكِبُ فِي ظِلِّهَا مِائَةَ عَامٍ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَنَسٍ وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2523}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Verily, in Paradise there is a tree, a rider will travel in it's shade for a hundred years." Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2524}{حَدَّثَنَا عَبَّاسٌ الدُّورِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنْ فِرَاسٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ فِي الْجَنَّةِ شَجَرَةٌ يَسِيرُ الرَّاكِبُ فِي ظِلِّهَا مِائَةَ عَامٍ لاَ يَقْطَعُهَا وَقَالَ ذَلِكَ الظِّلُّ الْمَمْدُودُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ أَبِي سَعِيدٍ ‏.‏\hadithno{2524}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa'eed Al-Khudri narrated that the Prophet (s.a.w) said:"In Paradise there is a tree, a rider will travel in its shade for a hundred years without reaching an end." He said: "And that is the extended shade}}
\hadithdefcmd{tirmidhi}{2525}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا زِيَادُ بْنُ الْحَسَنِ بْنِ الْفُرَاتِ الْقَزَّازُ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا فِي الْجَنَّةِ شَجَرَةٌ إِلاَّ وَسَاقُهَا مِنْ ذَهَبٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ أَبِي سَعِيدٍ ‏.‏\hadithno{2525}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"There is not a tree in Paradise except that its tree is of gold}}
\hadithdefcmd{tirmidhi}{2526}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ حَمْزَةَ الزَّيَّاتِ، عَنْ زِيَادٍ الطَّائِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قُلْنَا يَا رَسُولَ اللَّهِ مَا لَنَا إِذَا كُنَّا عِنْدَكَ رَقَّتْ قُلُوبُنَا وَزَهِدْنَا فِي الدُّنْيَا وَكُنَّا مِنْ أَهْلِ الآخِرَةِ فَإِذَا خَرَجْنَا مِنْ عِنْدِكَ فَآنَسْنَا أَهَالِيَنَا وَشَمَمْنَا أَوْلاَدَنَا أَنْكَرْنَا أَنْفُسَنَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ أَنَّكُمْ تَكُونُونَ إِذَا خَرَجْتُمْ مِنْ عِنْدِي كُنْتُمْ عَلَى حَالِكُمْ ذَلِكَ لَزَارَتْكُمُ الْمَلاَئِكَةُ فِي بُيُوتِكُمْ وَلَوْ لَمْ تُذْنِبُوا لَجَاءَ اللَّهُ بِخَلْقٍ جَدِيدٍ كَىْ يُذْنِبُوا فَيَغْفِرَ لَهُمْ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مِمَّ خُلِقَ الْخَلْقُ قَالَ ‏"‏ مِنَ الْمَاءِ ‏"‏ ‏.‏ قُلْنَا الْجَنَّةُ مَا بِنَاؤُهَا قَالَ ‏"‏ لَبِنَةٌ مِنْ فِضَّةٍ وَلَبِنَةٌ مِنْ ذَهَبٍ وَمِلاَطُهَا الْمِسْكُ الأَذْفَرُ وَحَصْبَاؤُهَا اللُّؤْلُؤُ وَالْيَاقُوتُ وَتُرْبَتُهَا الزَّعْفَرَانُ مَنْ يَدْخُلْهَا يَنْعَمْ وَلاَ يَبْأَسْ وَيُخَلَّدْ وَلاَ يَمُوتْ لاَ تَبْلَى ثِيَابُهُمْ وَلاَ يَفْنَى شَبَابُهُمْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ ثَلاَثَةٌ لاَ تُرَدُّ دَعْوَتُهُمُ الإِمَامُ الْعَادِلُ وَالصَّائِمُ حِينَ يُفْطِرُ وَدَعْوَةُ الْمَظْلُومِ يَرْفَعُهَا فَوْقَ الْغَمَامِ وَتُفَتَّحُ لَهَا أَبْوَابُ السَّمَاءِ وَيَقُولُ الرَّبُّ عَزَّ وَجَلَّ وَعِزَّتِي لأَنْصُرَنَّكِ وَلَوْ بَعْدَ حِينٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لَيْسَ إِسْنَادُهُ بِذَاكَ الْقَوِيِّ وَلَيْسَ هُوَ عِنْدِي بِمُتَّصِلٍ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ بِإِسْنَادٍ آخَرَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2526}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated:"We said: 'O Messenger of Allah! What is wrong with us that when we are with you our hearts are softened and we feel free of desire for this world, and we are of the people of the Hereafter. But when we depart from you and socialize with our families and our children, we do not recognize ourselves(i.e., we are changed persons)?' So the Messenger of Allah (s.a.w) said: 'If you were to be in that condition when you depart from me, the angels would have surely visited you in your houses. And if you did not sin, Allah would surely have brought anew creation that they may sin, so that then He may forgive them.'"He said: "I said: 'O Messenger of Allah! From what was the creation created?' He said: 'From water.' We said: 'Paradise, what is it constructed of?' He said,'Bricks of silver and bricks of gold. Its mortar is musk of a strong fragrance, and its pebbles are pearls and rubies, and its earth is saffron. Whoever enters it shall live and shall not suffer, and shall feel joy and shall not die, nor shall their clothes wear out, nor shall their youth come to an end.' Then he said: 'Three persons , their supplication is not rejected: The just ruler, the fasting person when he breaks his fast, and the supplication of the wronged person. It is raised up above the clouds, and the gates of Heaven are opened up for it, and the Lord, Blessed and Exalted says: I shall surely come to your aid, even if after a time}}
\hadithdefcmd{tirmidhi}{2527}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنِ النُّعْمَانِ بْنِ سَعْدٍ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ فِي الْجَنَّةِ لَغُرَفًا يُرَى ظُهُورُهَا مِنْ بُطُونِهَا وَبُطُونُهَا مِنْ ظُهُورِهَا ‏"‏ ‏.‏ فَقَامَ إِلَيْهِ أَعْرَابِيٌّ فَقَالَ لِمَنْ هِيَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ هِيَ لِمَنْ أَطَابَ الْكَلاَمَ وَأَطْعَمَ الطَّعَامَ وَأَدَامَ الصِّيَامَ وَصَلَّى لِلَّهِ بِاللَّيْلِ وَالنَّاسُ نِيَامٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُ أَهْلِ الْعِلْمِ فِي عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ هَذَا مِنْ قِبَلِ حِفْظِهِ وَهُوَ كُوفِيٌّ وَعَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ الْقُرَشِيُّ مَدَنِيٌّ وَهُوَ أَثْبَتُ مِنْ هَذَا ‏.‏\hadithno{2527}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ali narrated that the Messenger of Allah (s.a.w) said:"Indeed in Paradise there are chambers whose outside can be seen from their inside, and their inside can be seen fom their outside." A Bedouin stood and said: "Who are they for O Prophet of Allah?" he said: "For those who speak well, feed others, fast regularly, and perform Salat for Allah during the night while the people sleep}}
\hadithdefcmd{tirmidhi}{2528}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ أَبُو عَبْدِ الصَّمَدِ الْعَمِّيُّ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ اللَّهِ بْنِ قَيْسٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ فِي الْجَنَّةِ جَنَّتَيْنِ آنِيَتُهُمَا وَمَا فِيهِمَا مِنْ فِضَّةٍ وَجَنَّتَيْنِ آنِيَتُهُمَا وَمَا فِيهِمَا مِنْ ذَهَبٍ وَمَا بَيْنَ الْقَوْمِ وَبَيْنَ أَنْ يَنْظُرُوا إِلَى رَبِّهِمْ إِلاَّ رِدَاءُ الْكِبْرِيَاءِ عَلَى وَجْهِهِ فِي جَنَّةِ عَدْنٍ ‏"‏ ‏.‏ وَبِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ فِي الْجَنَّةِ لَخَيْمَةً مِنْ دُرَّةٍ مُجَوَّفَةٍ عَرْضُهَا سِتُّونَ مِيلاً فِي كُلِّ زَاوِيَةٍ مِنْهَا أَهْلٌ مَا يَرَوْنَ الآخَرِينَ يَطُوفُ عَلَيْهِمُ الْمُؤْمِنُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَأَبُو عِمْرَانَ الْجَوْنِيُّ اسْمُهُ عَبْدُ الْمَلِكِ بْنُ حَبِيبٍ وَأَبُو بَكْرِ بْنُ أَبِي مُوسَى قَالَ أَحْمَدُ بْنُ حَنْبَلٍ لاَ يُعْرَفُ اسْمُهُ ‏.‏ وَأَبُو مُوسَى الأَشْعَرِيُّ اسْمُهُ عَبْدُ اللَّهِ بْنُ قَيْسٍ وَأَبُو مَالِكٍ الأَشْعَرِيُّ اسْمُهُ سَعْدُ بْنُ طَارِقِ بْنِ أَشْيَمَ ‏.‏\hadithno{2528}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Bakr bin 'Abdullah bin Qais narrated from his father that the Prophet (s.a.w) said:"Indeed, in Paradise, there are two gardens, their vessels and all that are in them are of silver. And, there are two gardens, their vessels and all that are in them are of gold. There is nothing between the people and their seeing their Lord except the Cloak of Greatness upon his Face in the Garden of Eternity." And from the chain it is reported from the Prophet (s.a.w) he said: "Indeed in Paradise there is a great tent of hollowed pearl, its breadth is sixty miles, in every corner of it is a family, they do not see the others, and the believer goes around to them}}
\hadithdefcmd{tirmidhi}{2529}{حَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا شَرِيكٌ، عَنْ مُحَمَّدِ بْنِ جُحَادَةَ، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فِي الْجَنَّةِ مِائَةُ دَرَجَةٍ مَا بَيْنَ كُلِّ دَرَجَتَيْنِ مِائَةُ عَامٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2529}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"In Paradise, there are a hundred levels, between every two levels is (the distance of) a hundred years}}
\hadithdefcmd{tirmidhi}{2530}{حَدَّثَنَا قُتَيْبَةُ، وَأَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ الْبَصْرِيُّ، قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ صَامَ رَمَضَانَ وَصَلَّى الصَّلَوَاتِ وَحَجَّ الْبَيْتَ لاَ أَدْرِي أَذَكَرَ الزَّكَاةَ أَمْ لاَ إِلاَّ كَانَ حَقًّا عَلَى اللَّهِ أَنْ يَغْفِرَ لَهُ إِنْ هَاجَرَ فِي سَبِيلِ اللَّهِ أَوْ مَكَثَ بِأَرْضِهِ الَّتِي وُلِدَ بِهَا ‏"‏ ‏.‏ قَالَ مُعَاذٌ أَلاَ أُخْبِرُ بِهَذَا النَّاسَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ذَرِ النَّاسَ يَعْمَلُونَ فَإِنَّ فِي الْجَنَّةِ مِائَةَ دَرَجَةٍ مَا بَيْنَ كُلِّ دَرَجَتَيْنِ كَمَا بَيْنَ السَّمَاءِ وَالأَرْضِ وَالْفِرْدَوْسُ أَعْلَى الْجَنَّةِ وَأَوْسَطُهَا وَفَوْقَ ذَلِكَ عَرْشُ الرَّحْمَنِ وَمِنْهَا تُفَجَّرُ أَنْهَارُ الْجَنَّةِ فَإِذَا سَأَلْتُمُ اللَّهَ فَسَلُوهُ الْفِرْدَوْسَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا رُوِيَ هَذَا الْحَدِيثُ عَنْ هِشَامِ بْنِ سَعْدٍ عَنْ زَيْدِ بْنِ أَسْلَمَ عَنْ عَطَاءِ بْنِ يَسَارٍ عَنْ مُعَاذِ بْنِ جَبَلٍ وَهَذَا عِنْدِي أَصَحُّ مِنْ حَدِيثِ هَمَّامٍ عَنْ زَيْدِ بْنِ أَسْلَمَ عَنْ عَطَاءِ بْنِ يَسَارٍ عَنْ عُبَادَةَ بْنِ الصَّامِتِ ‏.‏ وَعَطَاءٌ لَمْ يُدْرِكْ مُعَاذَ بْنَ جَبَلٍ وَمُعَاذٌ قَدِيمُ الْمَوْتِ مَاتَ فِي خِلاَفَةِ عُمَرَ ‏.‏\hadithno{2530}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Mu'adh bin Jabal narrated that the Messenger of Allah (ﷺ) said:"Whoever fasts Ramadan, performs the Salat, performs Hajj to the House" - I do not know whether he mentioned Zakat or not - "except that it is binding on Allah that He forgive him, whether he emigrated in the cause of Allah, or remained in his land in which he was born." Mu'adh said: "Should I not inform the people of this?" The Messenger of Allah (ﷺ) said, "Leave the people to do deeds, for verily in Paradise there are a hundred levels, what is between every two levels is like what is between the heavens and the earth. Al-Firdaus is the highest of Paradise and its most expansive, and above that is the Throne of Ar-Rahman (the Most Merciful), and from it the rivers of Paradise are made to flow forth. So when you ask Allah, ask Him for Al-Firdaus}}
\hadithdefcmd{tirmidhi}{2531}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا هَمَّامٌ، حَدَّثَنَا زَيْدُ بْنُ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فِي الْجَنَّةِ مِائَةُ دَرَجَةٍ مَا بَيْنَ كُلِّ دَرَجَتَيْنِ كَمَا بَيْنَ السَّمَاءِ وَالأَرْضِ وَالْفِرْدَوْسُ أَعْلاَهَا دَرَجَةً وَمِنْهَا تُفَجَّرُ أَنْهَارُ الْجَنَّةِ الأَرْبَعَةُ وَمِنْ فَوْقِهَا يَكُونُ الْعَرْشُ فَإِذَا سَأَلْتُمُ اللَّهَ فَسَلُوهُ الْفِرْدَوْسَ ‏"‏ ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا هَمَّامٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، نَحْوَهُ ‏.‏\hadithno{2531}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ubadah bin As-Samit narrated that the Messenger of Allah (s.a.w) said:"In Paradise, there are a hundred levels, what is between every two levels is like what is between the heavens and the earth. Al-Firdaus is ts highest level, and from it the four rivers of Paradise are made to flow forth. So when you ask Allah, ask Him for Al-Firdaus." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2532}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ دَرَّاجٍ أَبِي السَّمْحِ، عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ فِي الْجَنَّةِ مِائَةَ دَرَجَةٍ لَوْ أَنَّ الْعَالَمِينَ اجْتَمَعُوا فِي إِحْدَاهُنَّ لَوَسِعَتْهُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{2532}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed narrated that the Prophet (ﷺ) said:"Indeed there are a hundred levels in Paradise, if all of the People of Paradise were to be gathered in one of them, it would have sufficed them}}
\hadithdefcmd{tirmidhi}{2533}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا فَرْوَةُ بْنُ أَبِي الْمَغْرَاءِ، أَخْبَرَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الْمَرْأَةَ مِنْ نِسَاءِ أَهْلِ الْجَنَّةِ لَيُرَى بَيَاضُ سَاقِهَا مِنْ وَرَاءِ سَبْعِينَ حُلَّةً حَتَّى يُرَى مُخُّهَا وَذَلِكَ بِأَنَّ اللَّهَ يَقُولُ‏:‏ ‏(‏كَأََنَّهُنَّ الْيَاقُوتُ وَالْمَرْجَانُ ‏)‏ فَأَمَّا الْيَاقُوتُ فَإِنَّهُ حَجَرٌ لَوْ أَدْخَلْتَ فِيهِ سِلْكًا ثُمَّ اسْتَصْفَيْتَهُ لأُرِيتَهُ مِنْ وَرَائِهِ ‏"‏ ‏.‏ حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2533}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Mas'ud narrated that the Prophet (s.a.w) said:"Indeed, a woman from the wives of the people of Paradise, the whiteness of her shin is visible through seventy garments until her marrow is seen, and that is because Allah, he Exalted, says: As if they are corundum and Marjan. So, as for the corundum, it is a stone that if you were to enter a wire through it, then you polished its cloudiness away, you would surely be able to see it through it." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2534}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، نَحْوَهُ بِمَعْنَاهُ وَلَمْ يَرْفَعْهُ ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ عَبِيدَةَ بْنِ حُمَيْدٍ وَهَكَذَا رَوَى جَرِيرٌ وَغَيْرُ وَاحِدٍ عَنْ عَطَاءِ بْنِ السَّائِبِ وَلَمْ يَرْفَعُوهُ ‏.‏ حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنْ عَطَاءِ بْنِ السَّائِبِ، نَحْوَ حَدِيثِ أَبِي الأَحْوَصِ وَلَمْ يَرْفَعْهُ أَصْحَابُ عَطَاءٍ وَهَذَا أَصَحُّ ‏.‏ ‏\hadithno{2534}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{(Another chain:) From 'Abdullah bin Mas'ud, similar in meaning, and he did not report it in Marfu' form. And this is more correct than the narration of 'Abidah bin Humaid (a narrator in no.2533), and it has been reported like this by Jarir and more than one from 'Ata' bin As-Sa'ib, and they did not mention it in Marfu' form.[Qutaibah repoted to us (he said): "Jarir reported to us, from 'Ata' bin As-Sa'ib and it is similar to the narration of Abu Al-Ahwas. The companions of 'Ata' did not narrate it in Marfu' form, and this is more correct}}
\hadithdefcmd{tirmidhi}{2535}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبِي، عَنْ فُضَيْلِ بْنِ مَرْزُوقٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ أَوَّلَ زُمْرَةٍ يَدْخُلُونَ الْجَنَّةَ يَوْمَ الْقِيَامَةِ ضَوْءُ وُجُوهِهِمْ عَلَى مِثْلِ ضَوْءِ الْقَمَرِ لَيْلَةَ الْبَدْرِ وَالزُّمْرَةُ الثَّانِيَةُ عَلَى مِثْلِ أَحْسَنِ كَوْكَبٍ دُرِّيٍّ فِي السَّمَاءِ لِكُلِّ رَجُلٍ مِنْهُمْ زَوْجَتَانِ عَلَى كُلِّ زَوْجَةٍ سَبْعُونَ حُلَّةً يُرَى مُخُّ سَاقِهَا مِنْ وَرَائِهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏. حَدَّثَنَا الْعَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَخْبَرَنَا شَيْبَانُ، عَنْ فِرَاسٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أَوَّلُ زُمْرَةٍ تَدْخُلُ الْجَنَّةَ عَلَى صُورَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ وَالثَّانِيَةُ عَلَى لَوْنِ أَحْسَنِ كَوْكَبٍ دُرِّيٍّ فِي السَّمَاءِ لِكُلِّ رَجُلٍ مِنْهُمْ زَوْجَتَانِ عَلَى كُلِّ زَوْجَةٍ سَبْعُونَ حُلَّةً يَبْدُو مُخُّ سَاقِهَا مِنْ وَرَائِهَا ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2535}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa'eed Al-Khudri narrated that the Prophet (s.a.w) said:"Indeed the first batch to enter Paradise will appear like the moon of a night that is full. The second will appear like the color of the most beautiful (brightest) star in the sky. Each man among them shall have two wives, each wife wearing seventy bracelets, with the marrow of their shins being visible from behind them." (Another chain) from Abu Sa'eed Al-Khudri who narrated that the Prophet SAW said: "The first batch to enter Paradise will appear like the moon of a night that it is full. The second will appear like the color of the most beautiful (brightest) star in the sky. Each man among them shall have two wives, each wife wearing seventy bracelets, with the marrow of their shins being visible from behind them}}
\hadithdefcmd{tirmidhi}{2536}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالاَ حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، عَنْ عِمْرَانَ الْقَطَّانِ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يُعْطَى الْمُؤْمِنُ فِي الْجَنَّةِ قُوَّةَ كَذَا وَكَذَا مِنَ الْجِمَاعِ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ أَوَيُطِيقُ ذَلِكَ قَالَ ‏"‏ يُعْطَى قُوَّةَ مِائَةٍ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ زَيْدِ بْنِ أَرْقَمَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ قَتَادَةَ عَنْ أَنَسٍ إِلاَّ مِنْ حَدِيثِ عِمْرَانَ الْقَطَّانِ ‏.‏\hadithno{2536}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Anas narrated that the Prophet (s.a.w) said:"The believer shall be given in paradise such and such strength in intercourse ." it was said: "O Messenger of Allah! And will he able to do that?" He said: "He will be given the strength of a hundred}}
\hadithdefcmd{tirmidhi}{2537}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَوَّلُ زُمْرَةٍ تَلِجُ الْجَنَّةَ صُورَتُهُمْ عَلَى صُورَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ لاَ يَبْصُقُونَ فِيهَا وَلاَ يَمْتَخِطُونَ وَلاَ يَتَغَوَّطُونَ آنِيَتُهُمْ فِيهَا الذَّهَبُ وَأَمْشَاطُهُمْ مِنَ الذَّهَبِ وَالْفِضَّةِ وَمَجَامِرُهُمْ مِنَ الأَلُوَّةِ وَرَشْحُهُمُ الْمِسْكُ وَلِكُلِّ وَاحِدٍ مِنْهُمْ زَوْجَتَانِ يُرَى مُخُّ سُوقِهِمَا مِنْ وَرَاءِ اللَّحْمِ مِنَ الْحُسْنِ لاَ اخْتِلاَفَ بَيْنَهُمْ وَلاَ تَبَاغُضَ قُلُوبُهُمْ قَلْبُ رَجُلٍ وَاحِدٍ يُسَبِّحُونَ اللَّهَ بُكْرَةً وَعَشِيًّا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَالأَلُوَّةُ هُوَ الْعُودُ ‏.‏\hadithno{2537}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"The first batch to enter Paradise will appear like the moon of a night that it is full, they do not spit, nor do their noses run, nor do they defecate. Their vessels are of gold, their combs are of silver and gold, their perfume is of Aluwwah, and their sweat is musk. Each one of them has two wives, so beautiful that the marrow of their shins can be seen through the flesh. There is no differing among them nor mutual hatred, and their hearts are like the heart of one man, and they glorify Allah morning and evening}}
\hadithdefcmd{tirmidhi}{2538}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا ابْنُ لَهِيعَةَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ دَاوُدَ بْنِ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ أَنَّ مَا يُقِلُّ ظُفُرٌ مِمَّا فِي الْجَنَّةِ بَدَا لَتَزَخْرَفَتْ لَهُ مَا بَيْنَ خَوَافِقِ السَّمَوَاتِ وَالأَرْضِ وَلَوْ أَنَّ رَجُلاً مِنْ أَهْلِ الْجَنَّةِ اطَّلَعَ فَبَدَا أَسَاوِرُهُ لَطَمَسَ ضَوْءَ الشَّمْسِ كَمَا تَطْمِسُ الشَّمْسُ ضَوْءَ النُّجُومِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ بِهَذَا الإِسْنَادِ إِلاَّ مِنْ حَدِيثِ ابْنِ لَهِيعَةَ ‏.‏ وَقَدْ رَوَى يَحْيَى بْنُ أَيُّوبَ هَذَا الْحَدِيثَ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ وَقَالَ عَنْ عُمَرَ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2538}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Dawud bin Amir bin Sa'd bin Abi Waqqas narrated from his father, from his grandfather that the Prophet (s.a.w) said:"If as little as what can be placed on a fingernail of what is in Paradise were to become apparent, it would have beautified all the far corners of the heavens and the earth. And if a man among the people of Paradise were to appear and his bracelets were to become apparent, it would have blotted out the light of the sun, as the sun blots out the light of the stars}}
\hadithdefcmd{tirmidhi}{2539}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَأَبُو هِشَامٍ الرِّفَاعِيُّ قَالاَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَامِرٍ الأَحْوَلِ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَهْلُ الْجَنَّةِ جُرْدٌ مُرْدٌ كُحْلٌ لاَ يَفْنَى شَبَابُهُمْ وَلاَ تَبْلَى ثِيَابُهُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2539}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated from the Messenger of Allah (s.a.w) that he said:"The people of Paradise are without body hair, Murd, with Kuhl(on their eyelids), their youth does not come to an end, and their clothes do not wear out}}
\hadithdefcmd{tirmidhi}{2540}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا رِشْدِينُ بْنُ سَعْدٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ دَرَّاجٍ أَبِي السَّمْحِ، عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي قَوْلِهِ‏:‏ ‏(‏وَفُرُشٍ مَرْفُوعَةٍ ‏)‏ قَالَ ‏"‏ ارْتِفَاعُهَا لَكَمَا بَيْنَ السَّمَاءِ وَالأَرْضِ مَسِيرَةَ خَمْسِمِائَةِ سَنَةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ رِشْدِينَ بْنِ سَعْدٍ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ فِي تَفْسِيرِ هَذَا الْحَدِيثِ إِنَّ مَعْنَاهُ الْفُرُشَ فِي الدَّرَجَاتِ وَبَيْنَ الدَّرَجَاتِ كَمَا بَيْنَ السَّمَاءِ وَالأَرْضِ ‏.‏\hadithno{2540}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Abu Sa'eed narrated concerning His (Allah's) statement "And couches, elevated ..." (Al Wa'qiah 56:34) that the Prophet (s.a.w) said:"Their elevation is indeed like what is between the heavens and the earth, a distance of five-hundred years}}
\hadithdefcmd{tirmidhi}{2541}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَحْيَى بْنِ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ وَذُكِرَ لَهُ سِدْرَةُ الْمُنْتَهَى قَالَ ‏ "‏ يَسِيرُ الرَّاكِبُ فِي ظِلِّ الْفَنَنِ مِنْهَا مِائَةَ سَنَةٍ أَوْ يَسْتَظِلُّ بِظِلِّهَا مِائَةُ رَاكِبٍ شَكَّ يَحْيَى فِيهَا فَرَاشُ الذَّهَبِ كَأَنَّ ثَمَرَهَا الْقِلاَلُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2541}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Asma' bint Abi Bakr narrated:"I heard the Messenger of Allah (s.a.w) while mentioning the Lote-Tree of the Utmost Boundary, saying: 'A rider will travel in the shade of one of its branches for a hundred years,' or 'a hundred riders will seek to shade themselves with its shade'-(lne of the narrators) Yahya' was in doubt- 'in it are butterflies of gold, it is as if its fruits are Qilal}}
\hadithdefcmd{tirmidhi}{2542}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ مُسْلِمٍ، عَنْ أَبِيهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا الْكَوْثَرُ قَالَ ‏"‏ ذَاكَ نَهْرٌ أَعْطَانِيهِ اللَّهُ يَعْنِي فِي الْجَنَّةِ أَشَدُّ بَيَاضًا مِنَ اللَّبَنِ وَأَحْلَى مِنَ الْعَسَلِ فِيهَا طَيْرٌ أَعْنَاقُهَا كَأَعْنَاقِ الْجُزُرِ ‏"‏ ‏.‏ قَالَ عُمَرُ إِنَّ هَذِهِ لَنَاعِمَةٌ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَكَلَتُهَا أَنْعَمُ مِنْهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ مُسْلِمٍ هُوَ ابْنُ أَخِي ابْنِ شِهَابٍ الزُّهْرِيِّ وَعَبْدُ اللَّهِ بْنُ مُسْلِمٍ قَدْ رَوَى عَنِ ابْنِ عُمَرَ وَأَنَسِ بْنِ مَالِكٍ ‏.‏\hadithno{2542}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah (s.a.w) was asked:"What is Al-Kawthar?" He said: "That is a river that Allah has given me"- that is, in Paradise- 'whiter than milk and sweeter than honey. In it are birds whose necks are like the necks of camels." 'Umar said: "Indeed this is plump and luxurious then." So the Messenger of Allah (s.a.w) said, "Those who consume it are more plumb than it}}
\hadithdefcmd{tirmidhi}{2543}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ أَخْبَرَنَا عَاصِمُ بْنُ عَلِيٍّ، حَدَّثَنَا الْمَسْعُودِيُّ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، سَأَلَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ هَلْ فِي الْجَنَّةِ مِنْ خَيْلٍ قَالَ ‏"‏ إِنِ اللَّهُ أَدْخَلَكَ الْجَنَّةَ فَلاَ تَشَاءُ أَنْ تُحْمَلَ فِيهَا عَلَى فَرَسٍ مِنْ يَاقُوتَةٍ حَمْرَاءَ يَطِيرُ بِكَ فِي الْجَنَّةِ حَيْثُ شِئْتَ إِلاَّ فَعَلْتَ ‏"‏ ‏.‏ قَالَ وَسَأَلَهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ هَلْ فِي الْجَنَّةِ مِنْ إِبِلٍ قَالَ فَلَمْ يَقُلْ لَهُ مِثْلَ مَا قَالَ لِصَاحِبِهِ قَالَ ‏"‏ إِنْ يُدْخِلْكَ اللَّهُ الْجَنَّةَ يَكُنْ لَكَ فِيهَا مَا اشْتَهَتْ نَفْسُكَ وَلَذَّتْ عَيْنُكَ ‏"‏ ‏.‏ حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ سُفْيَانَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَابِطٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ بِمَعْنَاهُ وَهَذَا أَصَحُّ مِنْ حَدِيثِ الْمَسْعُودِيِّ ‏.‏\hadithno{2543}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Sulaiman bin Buraidah narrated from his father that a man asked the Prophet (ﷺ):"O Messenger of Allah, are there horses in Paradise?" He said, "If Allah admits you into Paradise, you will not wish to be carried, on a horse of rubies that will fly with you wherever you want in Paradise except that you will do so." He said: "And a man asked him: 'O Messenger of Allah, are there camels in Paradise?'" He said: "So he (ﷺ) did not say what he said to his companion, rather, he (ﷺ) said: 'If Allah admits you into Paradise, you will have in it whatever is desired by your soul and pleasing to your eye.'" Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2544}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ سَمُرَةَ الأَحْمَسِيُّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ وَاصِلٍ، هُوَ ابْنُ السَّائِبِ عَنْ أَبِي سَوْرَةَ، عَنْ أَبِي أَيُّوبَ، قَالَ أَتَى النَّبِيَّ صلى الله عليه وسلم أَعْرَابِيٌّ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أُحِبُّ الْخَيْلَ أَفِي الْجَنَّةِ خَيْلٌ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ أُدْخِلْتَ الْجَنَّةَ أُتِيتَ بِفَرَسٍ مِنْ يَاقُوتَةٍ لَهُ جَنَاحَانِ فَحُمِلْتَ عَلَيْهِ ثُمَّ طَارَ بِكَ حَيْثُ شِئْتَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لَيْسَ إِسْنَادُهُ بِالْقَوِيِّ وَلاَ نَعْرِفُهُ مِنْ حَدِيثِ أَبِي أَيُّوبَ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَأَبُو سَوْرَةَ هُوَ ابْنُ أَخِي أَبِي أَيُّوبَ يُضَعَّفُ فِي الْحَدِيثِ ضَعَّفَهُ يَحْيَى بْنُ مَعِينٍ جِدًّا قَالَ وَسَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَقُولُ أَبُو سَوْرَةَ هَذَا مُنْكَرُ الْحَدِيثِ يَرْوِي مَنَاكِيرَ عَنْ أَبِي أَيُّوبَ لاَ يُتَابَعُ عَلَيْهَا ‏.‏\hadithno{2544}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Abu Ayyub narrated that a Bedouin came to the Prophet (s.a.w) and said:"O Messenger of Allah, indeed, I love horses. Are there horses in Paradise?" The Messenger of Allah (s.a.w) said: "If you are admitted into Paradise, you shall be brought a horse of rubies with two wings, then you shall be carried on it, then it will fly with you wherever you want}}
\hadithdefcmd{tirmidhi}{2545}{حَدَّثَنَا أَبُو هُرَيْرَةَ، مُحَمَّدُ بْنُ فِرَاسٍ الْبَصْرِيُّ حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا عِمْرَانُ أَبُو الْعَوَّامِ، عَنْ قَتَادَةَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ غَنْمٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ يَدْخُلُ أَهْلُ الْجَنَّةِ الْجَنَّةَ جُرْدًا مُرْدًا مُكَحَّلِينَ أَبْنَاءَ ثَلاَثِينَ أَوْ ثَلاَثٍ وَثَلاَثِينَ سَنَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَبَعْضُ أَصْحَابِ قَتَادَةَ رَوَوْا هَذَا عَنْ قَتَادَةَ مُرْسَلاً وَلَمْ يُسْنِدُوهُ ‏.‏\hadithno{2545}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Mu'adh bin Jabal narrated that the Prophet (s.a.w) said:"The people of Paradise shall enter Paradise without body hair, Murd, with Kuhl on their eyes, thirty years of age or thirty-three years}}
\hadithdefcmd{tirmidhi}{2546}{حَدَّثَنَا حُسَيْنُ بْنُ يَزِيدَ الطَّحَّانُ الْكُوفِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ ضِرَارِ بْنِ مُرَّةَ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَهْلُ الْجَنَّةِ عِشْرُونَ وَمِائَةُ صَفٍّ ثَمَانُونَ مِنْهَا مِنْ هَذِهِ الأُمَّةِ وَأَرْبَعُونَ مِنْ سَائِرِ الأُمَمِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً وَمِنْهُمْ مَنْ قَالَ عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ عَنْ أَبِيهِ وَحَدِيثُ أَبِي سِنَانٍ عَنْ مُحَارِبِ بْنِ دِثَارٍ حَسَنٌ ‏.‏ وَأَبُو سِنَانٍ اسْمُهُ ضِرَارُ بْنُ مُرَّةَ وَأَبُو سِنَانٍ الشَّيْبَانِيُّ اسْمُهُ سَعِيدُ بْنُ سِنَانٍ وَهُوَ بَصْرِيٌّ وَأَبُو سِنَانٍ الشَّامِيُّ اسْمُهُ عِيسَى بْنُ سِنَانٍ هُوَ الْقَسْمَلِيُّ ‏.‏\hadithno{2546}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Buraidah narrated from his father that the Messenger of Allah (s.a.w)said:"The people of Paradise are a hundred and twenty rows, eighty of them are from this nation, and forty are from the rest of the nations}}
\hadithdefcmd{tirmidhi}{2547}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَنْبَأَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ عَمْرَو بْنَ مَيْمُونٍ، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي قُبَّةٍ نَحْوًا مِنْ أَرْبَعِينَ فَقَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَرْضَوْنَ أَنْ تَكُونُوا رُبُعَ أَهْلِ الْجَنَّةِ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ أَتَرْضَوْنَ أَنْ تَكُونُوا ثُلُثَ أَهْلِ الْجَنَّةِ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ أَتَرْضَوْنَ أَنْ تَكُونُوا شَطْرَ أَهْلِ الْجَنَّةِ إِنَّ الْجَنَّةَ لاَ يَدْخُلُهَا إِلاَّ نَفْسٌ مُسْلِمَةٌ مَا أَنْتُمْ فِي الشِّرْكِ إِلاَّ كَالشَّعْرَةِ الْبَيْضَاءِ فِي جِلْدِ الثَّوْرِ الأَسْوَدِ أَوْ كَالشَّعْرَةِ السَّوْدَاءِ فِي جِلْدِ الثَّوْرِ الأَحْمَرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ وَأَبِي سَعِيدٍ الْخُدْرِيِّ ‏.‏\hadithno{2547}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Mas'ud narrated:"We were in a tent with the Messenger of Allah (s.a.w), about forty of us when the Messenger of Allah (s.a.w) said to us: 'Would you be pleased to be a quarter of the people of Paradise?' They said:'Yes.' He said: 'Would you be pleased to be a third of the people of Paradise?' They said: 'Yes.' He said: 'Would you be pleased to be one half of the people of Paradise? Verily none shall enter Paradise except a Muslim soul. And you are not with relation to Shirk except like the white hair on the hide of a black bull or like the black hair on the hide of a red bull." Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2548}{حَدَّثَنَا الْفَضْلُ بْنُ الصَّبَّاحِ الْبَغْدَادِيُّ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى الْقَزَّازُ، عَنْ خَالِدِ بْنِ أَبِي بَكْرٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بَابُ أُمَّتِي الَّذِي يَدْخُلُونَ مِنْهُ الْجَنَّةَ عَرْضُهُ مَسِيرَةُ الرَّاكِبِ الْجَوَادَ ثَلاَثًا ثُمَّ إِنَّهُمْ لَيُضْغَطُونَ عَلَيْهِ حَتَّى تَكَادُ مَنَاكِبُهُمْ تَزُولُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ قَالَ سَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَلَمْ يَعْرِفْهُ وَقَالَ لِخَالِدِ بْنِ أَبِي بَكْرٍ مَنَاكِيرُ عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ ‏.‏\hadithno{2548}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Salim bin 'Abdullah narrated from his father that the Messenger of Allah (s.a.w) said:"The breadth of the gate through which my Ummah shall enter Paradise is the distance that a good rider covers in three. (meaning three nights or three years and, and that [the latter] is more obvious) Despite that, they shall be constrained by it until their shoulders are almost crushed completely}}
\hadithdefcmd{tirmidhi}{2549}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ حَبِيبِ بْنِ أَبِي الْعِشْرِينَ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا حَسَّانُ بْنُ عَطِيَّةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ لَقِيَ أَبَا هُرَيْرَةَ فَقَالَ أَبُو هُرَيْرَةَ أَسْأَلُ اللَّهَ أَنْ يَجْمَعَ، بَيْنِي وَبَيْنَكَ فِي سُوقِ الْجَنَّةِ ‏.‏ فَقَالَ سَعِيدٌ أَفِيهَا سُوقٌ قَالَ نَعَمْ أَخْبَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَنَّ أَهْلَ الْجَنَّةِ إِذَا دَخَلُوهَا نَزَلُوا فِيهَا بِفَضْلِ أَعْمَالِهِمْ ثُمَّ يُؤْذَنُ فِي مِقْدَارِ يَوْمِ الْجُمُعَةِ مِنْ أَيَّامِ الدُّنْيَا فَيَزُورُونَ رَبَّهُمْ وَيُبْرِزُ لَهُمْ عَرْشَهُ وَيَتَبَدَّى لَهُمْ فِي رَوْضَةٍ مِنْ رِيَاضِ الْجَنَّةِ فَتُوضَعُ لَهُمْ مَنَابِرُ مِنْ نُورٍ وَمَنَابِرُ مِنْ لُؤْلُؤٍ وَمَنَابِرُ مِنْ يَاقُوتٍ وَمَنَابِرُ مِنْ زَبَرْجَدٍ وَمَنَابِرُ مِنْ ذَهَبٍ وَمَنَابِرُ مِنْ فِضَّةٍ وَيَجْلِسُ أَدْنَاهُمْ وَمَا فِيهِمْ مِنْ دَنِيٍّ عَلَى كُثْبَانِ الْمِسْكِ وَالْكَافُورِ وَمَا يُرَوْنَ أَنَّ أَصْحَابَ الْكَرَاسِيِّ بِأَفْضَلَ مِنْهُمْ مَجْلِسًا ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ قُلْتُ يَا رَسُولَ اللَّهِ وَهَلْ نَرَى رَبَّنَا قَالَ ‏"‏ نَعَمْ قَالَ هَلْ تَتَمَارَوْنَ فِي رُؤْيَةِ الشَّمْسِ وَالْقَمَرِ لَيْلَةَ الْبَدْرِ ‏"‏ ‏.‏ قُلْنَا لاَ ‏.‏ قَالَ ‏"‏ كَذَلِكَ لاَ تَتَمَارَوْنَ فِي رُؤْيَةِ رَبِّكُمْ وَلاَ يَبْقَى فِي ذَلِكَ الْمَجْلِسِ رَجُلٌ إِلاَّ حَاضَرَهُ اللَّهُ مُحَاضَرَةً حَتَّى يَقُولَ لِلرَّجُلِ مِنْهُمْ يَا فُلاَنُ ابْنَ فُلاَنٍ أَتَذْكُرُ يَوْمَ قُلْتَ كَذَا وَكَذَا فَيُذَكِّرُهُ بِبَعْضِ غَدَرَاتِهِ فِي الدُّنْيَا فَيَقُولُ يَا رَبِّ أَفَلَمْ تَغْفِرْ لِي فَيَقُولُ بَلَى فَبِسِعَةِ مَغْفِرَتِي بَلَغْتَ مَنْزِلَتَكَ هَذِهِ ‏.‏ فَبَيْنَمَا هُمْ عَلَى ذَلِكَ غَشِيَتْهُمْ سَحَابَةٌ مِنْ فَوْقِهِمْ فَأَمْطَرَتْ عَلَيْهِمْ طِيبًا لَمْ يَجِدُوا مِثْلَ رِيحِهِ شَيْئًا قَطُّ وَيَقُولُ رَبُّنَا تَبَارَكَ وَتَعَالَى قُومُوا إِلَى مَا أَعْدَدْتُ لَكُمْ مِنَ الْكَرَامَةِ فَخُذُوا مَا اشْتَهَيْتُمْ ‏.‏ قَالَ فَنَأْتِي سُوقًا قَدْ حَفَّتْ بِهِ الْمَلاَئِكَةُ فِيهِ مَا لَمْ تَنْظُرِ الْعُيُونُ إِلَى مِثْلِهِ وَلَمْ تَسْمَعِ الآذَانُ وَلَمْ يَخْطُرْ عَلَى الْقُلُوبِ فَيُحْمَلُ لَنَا مَا اشْتَهَيْنَا لَيْسَ يُبَاعُ فِيهَا وَلاَ يُشْتَرَى وَفِي ذَلِكَ السُّوقِ يَلْقَى أَهْلُ الْجَنَّةِ بَعْضُهُمْ بَعْضًا قَالَ فَيُقْبِلُ الرَّجُلُ ذُو الْمَنْزِلَةِ الْمُرْتَفِعَةِ فَيَلْقَى مَنْ هُوَ دُونَهُ وَمَا فِيهِمْ دَنِيٌّ فَيَرُوعُهُ مَا يَرَى عَلَيْهِ مِنَ اللِّبَاسِ فَمَا يَنْقَضِي آخِرُ حَدِيثِهِ حَتَّى يَتَخَيَّلَ إِلَيْهِ مَا هُوَ أَحْسَنُ مِنْهُ وَذَلِكَ أَنَّهُ لاَ يَنْبَغِي لأَحَدٍ أَنْ يَحْزَنَ فِيهَا ثُمَّ نَنْصَرِفُ إِلَى مَنَازِلِنَا فَتَتَلَقَّانَا أَزْوَاجُنَا فَيَقُلْنَ مَرْحَبًا وَأَهْلاً لَقَدْ جِئْتَ وَإِنَّ بِكَ مِنَ الْجَمَالِ أَفْضَلَ مِمَّا فَارَقْتَنَا عَلَيْهِ ‏.‏ فَنَقُولُ إِنَّا جَالَسْنَا الْيَوْمَ رَبَّنَا الْجَبَّارَ وَيَحِقُّنَا أَنْ نَنْقَلِبَ بِمِثْلِ مَا انْقَلَبْنَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَقَدْ رَوَى سُوَيْدُ بْنُ عَمْرٍو عَنِ الأَوْزَاعِيِّ شَيْئًا مِنْ هَذَا الْحَدِيثِ ‏.‏\hadithno{2549}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Hasan bin 'Atiyyah narrated from Sa'eed bin Al-Musayyab, that he met Abu Hurairah, and Abu Hurairah said:"I supplicate Allah to bring you and I together in the market of Paradise." So Sa'eed said: "Is there a market in it?" He said: "Yes, the messenger of Allah (s.a.w) informed me that: 'When the people of Paradise enter it, they shall take their places according to the virtue of their deeds. Then permission shall be granted to them to visit their Lord, for the length of a Friday from the days of the world. He shall present for them His Throne and He shall manifest the gardens of Paradise. Then lofty seats of light shall be erected for them, and lofty saets of pearl, and lofty seats or corundum, and lofty seats of peridots, and lofty seats of gold, and lofty seats of silver. And the lowest of them- and there is none of them that is low- shall sit upon a dune of musk and camphor, and they shall not regard those upon the chairs as having a better sitting place than them.' Abu Hurairah said: "I said: 'O Messenger of Allah, and will we see our Lord?' He (S.a.w) said: 'Yes.[He said: ] Do you doubt [concerning] seeing the sun, or the moon on a night when it is full?' We said: 'No.' He said: 'Likewise, you will not doubt concerning seeing your Lord. And they shall not remain in that meeting any man except Allah shall give him a lecture until he says to a man from among them: "O so-and – so son of so - and – so, do you remember the day when you said such-and-such.” And He will remind him of some of his betrayals in the world, so he will say: “O my Lord, did you not forgive me?” So He will say: “Indeed! It is by the vastness of My Forgiveness that you reached this station of yours.” So while they are engaged in this they shall be covered by a cloud that shall rain upon them a perfume, the like of whose smell they have not smelled, ever. And our Lord [Blessed and Exalted is He] shall say: “Arise to what I have prepared for you of generosity, and take whatever you desire.” Then, we will come to a market which the angels will have already surrounded. [In it] shall be what no eyes have seen the like of, nor ears have heard of, nor ever has it occurred in the hearts (of men). And there shall be carried to us whatever we desire. There shall be not be anything sold or bought in this market, and, in that market, the people of Paradise shall meet one another.' He said: 'So the person of high rank shall come and meet the one below him in rank- and there is none among them that is low- so he shall be impressed by the clothes he sees on him, their discussion shall not come to an end until he shall imagine upon himself what is more beautiful than it, and that is because it is not fitting for anyone to feel regret therein. Then we will return to our places and our wives shall meet us saying: “Welcome and greetings, you have come, and you have beauty greater than what you parted us with.” So we will say: “Indeed we sat today with our Lord, the Powerful, and it is fitting that we should return with what we have returned with.'” (Da'if)}}
\hadithdefcmd{tirmidhi}{2550}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَهَنَّادٌ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ، عَنِ النُّعْمَانِ بْنِ سَعْدٍ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ فِي الْجَنَّةِ لَسُوقًا مَا فِيهَا شِرَاءٌ وَلاَ بَيْعٌ إِلاَّ الصُّوَرَ مِنَ الرِّجَالِ وَالنِّسَاءِ فَإِذَا اشْتَهَى الرَّجُلُ صُورَةً دَخَلَ فِيهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{2550}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ali narrated that the Messenger of Allah (s.a.w) said:"Indeed in Paradise there is a market in which there is no buying nor selling- except for images of men and women. So whenever a man desires an image, he enters it}}
\hadithdefcmd{tirmidhi}{2551}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ الْبَجَلِيِّ، قَالَ كُنَّا جُلُوسًا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَنَظَرَ إِلَى الْقَمَرِ لَيْلَةَ الْبَدْرِ فَقَالَ ‏"‏ إِنَّكُمْ سَتُعْرَضُونَ عَلَى رَبِّكُمْ فَتَرَوْنَهُ كَمَا تَرَوْنَ هَذَا الْقَمَرَ لاَ تُضَامُونَ فِي رُؤْيَتِهِ فَإِنِ اسْتَطَعْتُمْ أَنْ لاَ تُغْلَبُوا عَلَى صَلاَةٍ قَبْلَ طُلُوعِ الشَّمْسِ وَصَلاَةٍ قَبْلَ غُرُوبِهَا فَافْعَلُوا ‏"‏ ‏.‏ ثُمَّ قَرَأََ‏:‏ ‏(‏سَبِّحْ بِحَمْدِ رَبِّكَ قَبْلَ طُلُوعِ الشَّمْسِ وَقَبْلَ الْغُرُوبِ ‏)‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2551}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Jarir bin 'Abdullah Al-Bajali narrated:"We were seated with the Prophet (s.a.w) when he looked towards the moon on the night of a full moon and said: "Indeed you shall be placed before your Lord and you shall see Him as you see this moon. You will see Him without trouble. So if you are able to keep from becoming overwhelmed from prayer before the rising of the sun and before its setting, then do so." Then he recited: And glorify the praises of your Lord before the setting}}
\hadithdefcmd{tirmidhi}{2552}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ صُهَيْبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي قَوْلِه‏:‏ ‏(‏لِلَّذِينَ أَحْسَنُوا الْحُسْنَى وَزِيَادَةٌ ‏)‏ قَالَ ‏"‏ إِذَا دَخَلَ أَهْلُ الْجَنَّةِ الْجَنَّةَ نَادَى مُنَادٍ إِنَّ لَكُمْ عِنْدَ اللَّهِ مَوْعِدًا ‏.‏ قَالُوا أَلَمْ يُبَيِّضْ وُجُوهَنَا وَيُنَجِّنَا مِنَ النَّارِ وَيُدْخِلْنَا الْجَنَّةَ قَالُوا بَلَى ‏.‏ قَالَ فَيُكْشَفُ الْحِجَابُ قَالَ فَوَاللَّهِ مَا أَعْطَاهُمْ شَيْئًا أَحَبَّ إِلَيْهِمْ مِنَ النَّظَرِ إِلَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ إِنَّمَا أَسْنَدَهُ حَمَّادُ بْنُ سَلَمَةَ وَرَفَعَهُ ‏.‏ وَرَوَى سُلَيْمَانُ بْنُ الْمُغِيرَةِ وَحَمَّادُ بْنُ زَيْدٍ هَذَا الْحَدِيثَ عَنْ ثَابِتٍ الْبُنَانِيِّ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى قَوْلَهُ ‏.‏\hadithno{2552}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Suhaib narrated concerning His (Allah's) statement:For those who do good is the best (reward) and even more- the Prophet (s.a.w) said: "When the people of Paradise enter Paradise, a caller shall call out: 'Indeed you have a promise with Allah.' They will say: 'Did he not whiten our faces, save us from the Fire, and admit us into Paradise?' They will say: 'Indeed.' Then the Veil shall be lifted." He said: "So, by Allah, He did not grant them anything more beloved to them than looking at Him}}
\hadithdefcmd{tirmidhi}{2553}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنِي شَبَابَةُ، عَنْ إِسْرَائِيلَ، عَنْ ثُوَيْرٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ أَدْنَى أَهْلِ الْجَنَّةِ مَنْزِلَةً لَمَنْ يَنْظُرُ إِلَى جِنَانِهِ وَأَزْوَاجِهِ وَنَعِيمِهِ وَخَدَمِهِ وَسُرُرِهِ مَسِيرَةَ أَلْفِ سَنَةٍ وَأَكْرَمَهُمْ عَلَى اللَّهِ مَنْ يَنْظُرُ إِلَى وَجْهِهِ غُدْوَةً وَعَشِيَّةً ‏"‏ ‏.‏ ثُمَّ قَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏:‏ ‏(‏وُجُوهٌ يَوْمَئِذٍ نَاضِرَةٌ * إِلَى رَبِّهَا نَاظِرَةٌ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ إِسْرَائِيلَ عَنْ ثُوَيْرٍ عَنِ ابْنِ عُمَرَ مَرْفُوعٌ ‏.‏ وَرَوَاهُ عَبْدُ الْمَلِكِ بْنُ أَبْجَرَ عَنْ ثُوَيْرٍ عَنِ ابْنِ عُمَرَ مَوْقُوفٌ ‏.‏ وَرَوَى عُبَيْدُ اللَّهِ الأَشْجَعِيُّ، عَنْ سُفْيَانَ، عَنْ ثُوَيْرٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَوْلَهُ وَلَمْ يَرْفَعْهُ حَدَّثَنَا بِذَلِكَ أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا عُبَيْدُ اللَّهِ الأَشْجَعِيُّ، عَنْ سُفْيَانَ، عَنْ ثُوَيْرٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، نَحْوَهُ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{2553}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Thuwair narrated from Ibn Umar, saying:The Messenger of Allah (s.a.w) said: "Indeed the least of the people of Paradise in rank is the one who shall look at his gardens, his wives, his bounties, his servants and his beds for the distance of a thousand years, and the noblest of them with Allah is the one who shall look at His Face morning and night." Then the Messenger of Allah (s.a.w) recited: Some faces on that day shall be radiant. They shall be looking at their Lord}}
\hadithdefcmd{tirmidhi}{2554}{حَدَّثَنَا مُحَمَّدُ بْنُ طَرِيفٍ الْكُوفِيُّ، حَدَّثَنَا جَابِرُ بْنُ نُوحٍ الْحِمَّانِيُّ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تُضَامُّونَ فِي رُؤْيَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ وَتُضَامُّونَ فِي رُؤْيَةِ الشَّمْسِ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ فَإِنَّكُمْ سَتَرَوْنَ رَبَّكُمْ كَمَا تَرَوْنَ الْقَمَرَ لَيْلَةَ الْبَدْرِ لاَ تُضَامُّونَ فِي رُؤْيَتِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَهَكَذَا رَوَى يَحْيَى بْنُ عِيسَى الرَّمْلِيُّ وَغَيْرُ وَاحِدٍ عَنِ الأَعْمَشِ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَى عَبْدُ اللَّهِ بْنُ إِدْرِيسَ عَنِ الأَعْمَشِ عَنْ أَبِي صَالِحٍ عَنْ أَبِي سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَحَدِيثُ ابْنِ إِدْرِيسَ عَنِ الأَعْمَشِ غَيْرُ مَحْفُوظٍ وَحَدِيثُ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَصَحُّ وَهَكَذَا رَوَاهُ سُهَيْلُ بْنُ أَبِي صَالِحٍ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ هَذَا الْوَجْهِ مِثْلُ هَذَا الْحَدِيثِ وَهُوَ حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2554}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Do you crowd one another in order to see the moon on the night of a full moon? Do you crowd one another in order to see the sun?" They said: "No." He said: "So verily, you shall see your Lord as you see the moon on the night of a full moon, you shall not crowd one another to see Him." Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2555}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يَقُولُ لأَهْلِ الْجَنَّةِ يَا أَهْلَ الْجَنَّةِ ‏.‏ فَيَقُولُونَ لَبَّيْكَ رَبَّنَا وَسَعْدَيْكَ ‏.‏ فَيَقُولُ هَلْ رَضِيتُمْ فَيَقُولُونَ مَا لَنَا لاَ نَرْضَى وَقَدْ أَعْطَيْتَنَا مَا لَمْ تُعْطِ أَحَدًا مِنْ خَلْقِكَ ‏.‏ فَيَقُولُ أَنَا أُعْطِيكُمْ أَفْضَلَ مِنْ ذَلِكَ ‏.‏ قَالُوا وَأَىُّ شَيْءٍ أَفْضَلُ مِنْ ذَلِكَ قَالَ أُحِلُّ عَلَيْكُمْ رِضْوَانِي فَلاَ أَسْخَطُ عَلَيْكُمْ أَبَدًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2555}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Sa'eed Al-Khudri narrated that the Messenger of Allah (s.a.w) said:"Indeed, Allah will say to the people of Paradise: 'O people of Paradise!' They will say: 'We respond to You, O our Lord,and we are at Your service.' Then He will say: 'Are you pleased?' They will say: 'Why should we not be pleased when You have given us what you have not given anyone from Your creation.' So He will say: 'I shall give you what is greater than that.' They will say: 'And what is greater than that?' He will say: 'I shall cover you in My Pleasure and I shall not become angry with you ever}}
\hadithdefcmd{tirmidhi}{2556}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ هِلاَلِ بْنِ عَلِيٍّ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ أَهْلَ الْجَنَّةِ لَيَتَرَاءَوْنَ فِي الْغُرْفَةِ كَمَا تَتَرَاءَوْنَ الْكَوْكَبَ الشَّرْقِيَّ أَوِ الْكَوْكَبَ الْغَرْبِيَّ الْغَارِبَ فِي الأُفُقِ أَوِ الطَّالِعَ فِي تَفَاضُلِ الدَّرَجَاتِ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ أُولَئِكَ النَّبِيُّونَ ‏.‏ قَالَ ‏"‏ بَلَى وَالَّذِي نَفْسِي بِيَدِهِ وَأَقْوَامٌ آمَنُوا بِاللَّهِ وَرَسُولِهِ وَصَدَّقُوا الْمُرْسَلِينَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2556}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Prophet (s.a.w) said:"Indeed, the people of Paradise shall see the upper chamber like they see the eastern star, or the western star, disappearing in the far edge of the sky, or ascending due to the differences in levels." They said: "Are those the Prophets?" He said: "Yes. By the One in Whose Hand is my soul, and groups who had faith in Allah and His Messenger, and believed in the Messengers}}
\hadithdefcmd{tirmidhi}{2557}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ يَجْمَعُ اللَّهُ النَّاسَ يَوْمَ الْقِيَامَةِ فِي صَعِيدٍ وَاحِدٍ ثُمَّ يَطَّلِعُ عَلَيْهِمْ رَبُّ الْعَالَمِينَ فَيَقُولُ أَلاَ يَتْبَعُ كُلُّ إِنْسَانٍ مَا كَانُوا يَعْبُدُونَهُ ‏.‏ فَيُمَثَّلُ لِصَاحِبِ الصَّلِيبِ صَلِيبُهُ وَلِصَاحِبِ التَّصَاوِيرِ تَصَاوِيرُهُ وَلِصَاحِبِ النَّارِ نَارُهُ فَيَتْبَعُونَ مَا كَانُوا يَعْبُدُونَ وَيَبْقَى الْمُسْلِمُونَ فَيَطَّلِعُ عَلَيْهِمْ رَبُّ الْعَالَمِينَ فَيَقُولُ أَلاَ تَتَّبِعُونَ النَّاسَ فَيَقُولُونَ نَعُوذُ بِاللَّهِ مِنْكَ نَعُوذُ بِاللَّهِ مِنْكَ اللَّهُ رَبُّنَا هَذَا مَكَانُنَا حَتَّى نَرَى رَبَّنَا ‏.‏ وَهُوَ يَأْمُرُهُمْ وَيُثَبِّتُهُمْ ثُمَّ يَتَوَارَى ثُمَّ يَطَّلِعُ فَيَقُولُ أَلاَ تَتَّبِعُونَ النَّاسَ فَيَقُولُونَ نَعُوذُ بِاللَّهِ مِنْكَ نَعُوذُ بِاللَّهِ مِنْكَ اللَّهُ رَبُّنَا وَهَذَا مَكَانُنَا حَتَّى نَرَى رَبَّنَا ‏.‏ وَهُوَ يَأْمُرُهُمْ وَيُثَبِّتُهُمْ ‏"‏ ‏.‏ قَالُوا وَهَلْ نَرَاهُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَهَلْ تُضَارُّونَ فِي رُؤْيَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ ‏"‏ ‏.‏ قَالُوا لاَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَإِنَّكُمْ لاَ تُضَارُّونَ فِي رُؤْيَتِهِ تِلْكَ السَّاعَةَ ثُمَّ يَتَوَارَى ثُمَّ يَطَّلِعُ فَيُعَرِّفُهُمْ نَفْسَهُ ثُمَّ يَقُولُ أَنَا رَبُّكُمْ فَاتَّبِعُونِي ‏.‏ فَيَقُومُ الْمُسْلِمُونَ وَيُوضَعُ الصِّرَاطُ فَيَمُرُّونَ عَلَيْهِ مِثْلَ جِيَادِ الْخَيْلِ وَالرِّكَابِ وَقَوْلُهُمْ عَلَيْهِ سَلِّمْ سَلِّمْ ‏.‏ وَيَبْقَى أَهْلُ النَّارِ فَيُطْرَحُ مِنْهُمْ فِيهَا فَوْجٌ ثُمَّ يُقَالُ هَلِ امْتَلأْتِ فَتَقُولُ هَلْ مِنْ مَزِيدٍ ‏.‏ ثُمَّ يُطْرَحُ فِيهَا فَوْجٌ فَيُقَالُ هَلِ امْتَلأْتِ ‏.‏ فَتَقُولُ هَلْ مِنْ مَزِيدٍ ‏.‏ حَتَّى إِذَا أُوعِبُوا فِيهَا وَضَعَ الرَّحْمَنُ قَدَمَهُ فِيهَا وَأُزْوِيَ بَعْضُهَا إِلَى بَعْضٍ ثُمَّ قَالَ قَطْ قَالَتْ قَطْ قَطْ فَإِذَا أَدْخَلَ اللَّهُ أَهْلَ الْجَنَّةِ الْجَنَّةَ وَأَهْلَ النَّارِ النَّارَ قَالَ أُتِيَ بِالْمَوْتِ مُلَبَّبًا فَيُوقَفُ عَلَى السُّورِ الَّذِي بَيْنَ أَهْلِ الْجَنَّةِ وَأَهْلِ النَّارِ ثُمَّ يُقَالُ يَا أَهْلَ الْجَنَّةِ ‏.‏ فَيَطَّلِعُونَ خَائِفِينَ ثُمَّ يُقَالُ يَا أَهْلَ النَّارِ ‏.‏ فَيَطَّلِعُونَ مُسْتَبْشِرِينَ يَرْجُونَ الشَّفَاعَةَ فَيُقَالُ لأَهْلِ الْجَنَّةِ وَأَهْلِ النَّارِ هَلْ تَعْرِفُونَ هَذَا فَيَقُولُونَ هَؤُلاَءِ وَهَؤُلاَءِ قَدْ عَرَفْنَاهُ هُوَ الْمَوْتُ الَّذِي وُكِّلَ بِنَا ‏.‏ فَيُضْجَعُ فَيُذْبَحُ ذَبْحًا عَلَى السُّورِ الَّذِي بَيْنَ الْجَنَّةِ وَالنَّارِ ثُمَّ يُقَالُ يَا أَهْلَ الْجَنَّةِ خُلُودٌ لاَ مَوْتَ وَيَا أَهْلَ النَّارِ خُلُودٌ لاَ مَوْتَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ - وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم رِوَايَاتٌ كَثِيرَةٌ مِثْلُ هَذَا مَا يُذْكَرُ فِيهِ أَمْرُ الرُّؤْيَةِ أَنَّ النَّاسَ يَرَوْنَ رَبَّهُمْ وَذِكْرُ الْقَدَمِ وَمَا أَشْبَهَ هَذِهِ الأَشْيَاءَ وَالْمَذْهَبُ فِي هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنَ الأَئِمَّةِ مِثْلِ سُفْيَانَ الثَّوْرِيِّ وَمَالِكِ بْنِ أَنَسٍ وَابْنِ الْمُبَارَكِ وَابْنِ عُيَيْنَةَ وَوَكِيعٍ وَغَيْرِهِمْ أَنَّهُمْ رَوَوْا هَذِهِ الأَشْيَاءَ ثُمَّ قَالُوا تُرْوَى هَذِهِ الأَحَادِيثُ وَنُؤْمِنُ بِهَا وَلاَ يُقَالُ كَيْفَ وَهَذَا الَّذِي اخْتَارَهُ أَهْلُ الْحَدِيثِ أَنْ تُرْوَى هَذِهِ الأَشْيَاءُ كَمَا جَاءَتْ وَيُؤْمَنُ بِهَا وَلاَ تُفَسَّرُ وَلاَ تُتَوَهَّمُ وَلاَ يُقَالُ كَيْفَ وَهَذَا أَمْرُ أَهْلِ الْعِلْمِ الَّذِي اخْتَارُوهُ وَذَهَبُوا إِلَيْهِ ‏.‏ وَمَعْنَى قَوْلِهِ فِي الْحَدِيثِ ‏"‏ فَيُعَرِّفُهُمْ نَفْسَهُ ‏"‏ ‏.‏ يَعْنِي يَتَجَلَّى لَهُمْ ‏.‏\hadithno{2557}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Allah will gather mankind on the Day of Resurrection on a single plane, then the Lord of the Worlds will come to them and say: 'Let every person follow what they used to worship.' SO to the worshipper of the cross, his cross shall be symbolized to him, and to the worshipper of images his images, and to the worshipper of fire his fire. They will follow what they used to worship, and the Muslims will remain. Then the Lord of the Worlds will come to them and say: 'Do you not follow the people?' So they will say: 'We seek refuge in Allah from you, we seek refuge in Allah from you, Allah is our Lord, and we shall remain here until we see our Lord.' And He orders them and makes them firm.'"Thy said: "And you will see Him, O Messenger of Allah?" He said: "Are you harmed in seeing the moon on the night of a full moon?" They said: "No, O Messenger of Allah." He said: "So you will not be harmed in seeing Him at that hour. Then He will conceal Himself, then He will come, and He will make them recognize Him, then He will say: "I am your Lord, so follow Me." So the Muslims will arise and the Sirat shall be placed, and they shall be placed, and they shall pass by it the like of excellent horses and camels and their statement upon it shall be, "Grant them safety, grant them safety." And the people of Fire shall remain, then a party of them shall be cast down into it, and it shall be said (to the Fire): 'Have you become full?' So it shall say: Is there more? Then a party of them shall be cast down into it, and it shall be said: 'Have you become full?' So it shall say: Is there more? Until when they are all included into it, Ar-Rahman (the Most-Merciful) shall place His foot in it and its sides shall be all brought together, then He will say: 'Enough.' It will say 'Enough, enough.' So when Allah, the Exalted, has admitted the people of Paradise into Paradise and the people of Fire into Fire"- [He said:]- "Death shall be brought in by the collar and stood on the wall that is between the people of Paradise and the people of the Fire, then it will be said: 'O people of Paradise!' They will come near, afraid. Then it will be said: 'O people of the Fire!' They will come rejoicing, hoping for intercession. Then it will be said to the people of Paradise and the people of the Fire: 'Do you recognize this?' So they will-both of them-say: 'We recognize it. It is Death which was given charge of us,' so it will be laid down and slaughtered upon the wall [the one that is between Paradise and the Fire], then it will be said: 'O people of Paradise! Everlasting life without death!' And 'O people of the Fire! Everlasting life without death}}
\hadithdefcmd{tirmidhi}{2558}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبِي، عَنْ فُضَيْلِ بْنِ مَرْزُوقٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، يَرْفَعُهُ قَالَ ‏ "‏ إِذَا كَانَ يَوْمُ الْقِيَامَةِ أُتِيَ بِالْمَوْتِ كَالْكَبْشِ الأَمْلَحِ فَيُوقَفُ بَيْنَ الْجَنَّةِ وَالنَّارِ فَيُذْبَحُ وَهُمْ يَنْظُرُونَ فَلَوْ أَنَّ أَحَدًا مَاتَ فَرَحًا لَمَاتَ أَهْلُ الْجَنَّةِ وَلَوْ أَنَّ أَحَدًا مَاتَ حَزَنًا لَمَاتَ أَهْلُ النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2558}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Attiyah narrated from Abu Sa'eed in Marfu' form:"When it is the Day of Resurrection, Death shall be brought as a mixed black-white ram. It shall be stood between Paradise and the Fire, and then slaughtered while they watch. If anyone were to die of joy, then surely the people of Paradise and the Fire, and then slaughtered while they watch. If anyone were to die of joy, then surely the people of Paradise would die, and if anyone were to die of grief, then surely the people of the Fire would die}}
\hadithdefcmd{tirmidhi}{2559}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا عَمْرُو بْنُ عَاصِمٍ، أَخْبَرَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ حُمَيْدٍ، وَثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ حُفَّتِ الْجَنَّةُ بِالْمَكَارِهِ وَحُفَّتِ النَّارُ بِالشَّهَوَاتِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2559}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Anas narrated that the Messenger of Allah (s.a.w) said:"Paradise is surrounded by hardships, and the Fire is surrounded by desires}}
\hadithdefcmd{tirmidhi}{2560}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَمَّا خَلَقَ اللَّهُ الْجَنَّةَ وَالنَّارَ أَرْسَلَ جِبْرِيلَ إِلَى الْجَنَّةِ فَقَالَ انْظُرْ إِلَيْهَا وَإِلَى مَا أَعْدَدْتُ لأَهْلِهَا فِيهَا قَالَ فَجَاءَهَا وَنَظَرَ إِلَيْهَا وَإِلَى مَا أَعَدَّ اللَّهُ لأَهْلِهَا فِيهَا قَالَ فَرَجَعَ إِلَيْهِ قَالَ فَوَعِزَّتِكَ لاَ يَسْمَعُ بِهَا أَحَدٌ إِلاَّ دَخَلَهَا ‏.‏ فَأَمَرَ بِهَا فَحُفَّتْ بِالْمَكَارِهِ فَقَالَ ارْجِعْ إِلَيْهَا فَانْظُرْ إِلَى مَا أَعْدَدْتُ لأَهْلِهَا فِيهَا قَالَ فَرَجَعَ إِلَيْهَا فَإِذَا هِيَ قَدْ حُفَّتْ بِالْمَكَارِهِ فَرَجَعَ إِلَيْهِ فَقَالَ وَعِزَّتِكَ لَقَدْ خِفْتُ أَنْ لاَ يَدْخُلَهَا أَحَدٌ ‏.‏ قَالَ اذْهَبْ إِلَى النَّارِ فَانْظُرْ إِلَيْهَا وَإِلَى مَا أَعْدَدْتُ لأَهْلِهَا فِيهَا ‏.‏ فَإِذَا هِيَ يَرْكَبُ بَعْضُهَا بَعْضًا فَرَجَعَ إِلَيْهِ فَقَالَ وَعِزَّتِكَ لاَ يَسْمَعُ بِهَا أَحَدٌ فَيَدْخُلُهَا ‏.‏ فَأَمَرَ بِهَا فَحُفَّتْ بِالشَّهَوَاتِ فَقَالَ ارْجِعْ إِلَيْهَا ‏.‏ فَرَجَعَ إِلَيْهَا فَقَالَ وَعِزَّتِكَ لَقَدْ خَشِيتُ أَنْ لاَ يَنْجُوَ مِنْهَا أَحَدٌ إِلاَّ دَخَلَهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2560}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"When Allah created Paradise and the Fire, He sent Jibril to Paradise , saying: 'Look at it and at what I have prepared in it for its inhabitants.'" He (s.a.w) said: "So he came to it and looked at it, and at what Allah had prepared in it. He (Jibril) said: 'Indeed, by your Might, none shall hear of it except that he shall enter it.' Then He gave the order for it to be surrounded with hardships. He said: 'Return to it and look at it, and at what I have prepared in it for its inhabitants.'" He (s.a.w) said: "So he returned to it and found it surrounded with hardships. He returned to Him and said: 'Indeed, by your Might, I fear that none shall enter it.' He (s.a.w) said: 'Go to the Fire and look at it and at what I have prepared in it for its inhabitants.' So he found it, one part of it riding the other. So he returned to Him and said: 'Indeed, by your Might, none shall hear of it and then enter it.' So He gave the order for it to be surrounded with desires, then He said: 'Return to it.,' so he (Jibril) returned to it, then he said: 'Indeed, by Your Might, I fear that none shall be saved from it except that he shall enter it}}
\hadithdefcmd{tirmidhi}{2561}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ احْتَجَّتِ الْجَنَّةُ وَالنَّارُ فَقَالَتِ الْجَنَّةُ يَدْخُلُنِي الضُّعَفَاءُ وَالْمَسَاكِينُ ‏.‏ وَقَالَتِ النَّارُ يَدْخُلُنِي الْجَبَّارُونَ وَالْمُتَكَبِّرُونَ ‏.‏ فَقَالَ لِلنَّارِ أَنْتِ عَذَابِي أَنْتَقِمُ بِكِ مِمَّنْ شِئْتُ ‏.‏ وَقَالَ لِلْجَنَّةِ أَنْتِ رَحْمَتِي أَرْحَمُ بِكِ مَنْ شِئْتُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2561}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Paradise and the Fire debated. Paradise said: 'The weak and the poor shall enter me,' and the Fire said: 'The tyrants and the proud shall enter me.' So He said to the Fire: 'You are My Punishment, I take vengeance through you from whom I will,' and He said to Paradise: 'You are My Mercy I show mercy through you to whom I will}}
\hadithdefcmd{tirmidhi}{2562}{حَدَّثَنَا سُوَيْدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا رِشْدِينُ بْنُ سَعْدٍ، حَدَّثَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ دَرَّاجٍ، عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَدْنَى أَهْلِ الْجَنَّةِ الَّذِي لَهُ ثَمَانُونَ أَلْفَ خَادِمٍ وَاثْنَتَانِ وَسَبْعُونَ زَوْجَةً وَتُنْصَبُ لَهُ قُبَّةٌ مِنْ لُؤْلُؤٍ وَزَبَرْجَدٍ وَيَاقُوتٍ كَمَا بَيْنَ الْجَابِيَةِ إِلَى صَنْعَاءَ ‏"‏ ‏.‏ وَبِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ مَاتَ مِنْ أَهْلِ الْجَنَّةِ مِنْ صَغِيرٍ أَوْ كَبِيرٍ يُرَدُّونَ بَنِي ثَلاَثِينَ فِي الْجَنَّةِ لاَ يَزِيدُونَ عَلَيْهَا أَبَدًا وَكَذَلِكَ أَهْلُ النَّارِ ‏"‏ ‏.‏ وَبِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ عَلَيْهِمُ التِّيجَانَ إِنَّ أَدْنَى لُؤْلُؤَةٍ مِنْهَا لَتُضِيءُ مَا بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ رِشْدِينَ بْنِ سَعْدٍ ‏.‏\hadithno{2562}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Abu Sa'eed Al-Khudri narrated that the Messenger of Allah (s.a.w) said:"The least of the people of Paradise in position is the one with eighty thousand servants and seventy-two wives. He shall have a tent of pearl, peridot, and corundum set up for him,(the size of which is) like that which is between Al-Jabiyyah and Sana'a."And with this chain, it is narrated from the Prophet (s.a.w) that he said: "Whoever of the people of (destined to enter) Paradise dies, young or old, they shall be brought back in Paradise thirty years old, they will not increase in that ever, and likewise the people of the Fire." And with this chain, it is narrated from the Prophet (s.a.w) that he said: "There are upon them crowns, the least of its pearls would illuminate what is between the East and the West}}
\hadithdefcmd{tirmidhi}{2563}{حَدَّثَنَا بُنْدَارٌ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنَا أَبِي، عَنْ عَامِرٍ الأَحْوَلِ، عَنْ أَبِي الصِّدِّيقِ النَّاجِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْمُؤْمِنُ إِذَا اشْتَهَى الْوَلَدَ فِي الْجَنَّةِ كَانَ حَمْلُهُ وَوَضْعُهُ وَسِنُّهُ فِي سَاعَةٍ كَمَا يَشْتَهِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي هَذَا فَقَالَ بَعْضُهُمْ فِي الْجَنَّةِ جِمَاعٌ وَلاَ يَكُونُ وَلَدٌ ‏.‏ هَكَذَا رُوِيَ عَنْ طَاوُسٍ وَمُجَاهِدٍ وَإِبْرَاهِيمَ النَّخَعِيِّ ‏.‏ وَقَالَ مُحَمَّدٌ قَالَ إِسْحَاقُ بْنُ إِبْرَاهِيمَ فِي حَدِيثِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ إِذَا اشْتَهَى الْمُؤْمِنُ الْوَلَدَ فِي الْجَنَّةِ كَانَ فِي سَاعَةٍ وَاحِدَةٍ كَمَا يَشْتَهِي ‏"‏ ‏.‏ وَلَكِنْ لاَ يَشْتَهِي ‏.‏ قَالَ مُحَمَّدٌ وَقَدْ رُوِيَ عَنْ أَبِي رَزِينٍ الْعُقَيْلِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ أَهْلَ الْجَنَّةِ لاَ يَكُونُ لَهُمْ فِيهَا وَلَدٌ ‏"‏ ‏.‏ وَأَبُو الصِّدِّيقِ النَّاجِيُّ اسْمُهُ بَكْرُ بْنُ عَمْرٍو وَيُقَالُ بَكْرُ بْنُ قَيْسٍ أَيْضًا ‏.‏\hadithno{2563}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sa'eed Al-Khudri narrated that the Messenger of Allah (s.a.w) said:"The believer, when he desires a child in Paradise, he shall be carried (in pregnancy), born, and complete his aging in an hour as he desires." The people of knowledge disagreed concerning this, so some of them said that in Paradise there is intercourse but no births. It has been reported like this from Tawus, Mujahid and Ibrahim AnNakha'i. Muhammad said: "Concerning the Hadith of the Prophet SAW: 'When the believer desires a child in Paradise, it shall be in an hour as he desires' Ishaq bin Ibrahim said: 'But he will not desire." Muhammad said: "And it has been reported from Abu Razin Al- 'Uqaili from the Prophet SAW that he said: 'Indeed the people of Paradise shall not have children therein}}
\hadithdefcmd{tirmidhi}{2564}{حَدَّثَنَا هَنَّادٌ، وَأَحْمَدُ بْنُ مَنِيعٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ، عَنِ النُّعْمَانِ بْنِ سَعْدٍ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ فِي الْجَنَّةِ لَمُجْتَمَعًا لِلْحُورِ الْعِينِ يُرَفِّعْنَ بِأَصْوَاتٍ لَمْ يَسْمَعِ الْخَلاَئِقُ مِثْلَهَا قَالَ يَقُلْنَ نَحْنُ الْخَالِدَاتُ فَلاَ نَبِيدُ وَنَحْنُ النَّاعِمَاتُ فَلاَ نَبْأَسُ وَنَحْنُ الرَّاضِيَاتُ فَلاَ نَسْخَطُ طُوبَى لِمَنْ كَانَ لَنَا وَكُنَّا لَهُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{2564}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ali narrated that the Messenger of Allah (s.a.w) said:"Indeed in Paradise there is a gathering for Al-Hur Al-'Ein wherein they rasie their voices. The creatures have not heard the likes of them." [He said:] "They say: 'We are the eternal ones, we shall not die. We are the ones who live in joy and comfort, we have no needs. We are the pleased ones, we do not get angry. Tuba(good news) to the one who belongs to us and we to him.'" Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2565}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، فِي قَوْلِهِ عَزَّ وَجَلَّ‏:‏ ‏(‏فَهُمْ فِي رَوْضَةٍ يُحْبَرُونَ ‏)‏ قَالَ السَّمَّاعُ ‏.‏ وَمَعْنَى السَّمَّاعِ مِثْلَ مَا وَرَدَ فِي الْحَدِيثِ أَنَّ الْحُورَ الْعِينَ يُرَفِّعْنَ بِأَصْوَاتِهِنَّ ‏.‏\hadithno{2565}\hadithgrade{Zubair Ali Zai: Isnaad Sahih}\hadithtrans{From Yahya bin Abi Kathir, concerning His (Allah's), the Mighty and Glorious, statement:"Then they shall be in gardens living luxuriously" He said: "Listening."And the meaning of listening is similar to what has been mentioned in the Hadith that Al-Hur Al-'Ein raise their voices}}
\hadithdefcmd{tirmidhi}{2566}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي الْيَقْظَانِ، عَنْ زَاذَانَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ عَلَى كُثْبَانِ الْمِسْكِ - أُرَاهُ قَالَ يَوْمَ الْقِيَامَةِ يَغْبِطُهُمُ الأَوَّلُونَ وَالآخِرُونَ رَجُلٌ يُنَادِي بِالصَّلَوَاتِ الْخَمْسِ فِي كُلِّ يَوْمٍ وَلَيْلَةٍ وَرَجُلٌ يَؤُمُّ قَوْمًا وَهُمْ بِهِ رَاضُونَ وَعَبْدٌ أَدَّى حَقَّ اللَّهِ وَحَقَّ مَوَالِيهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ سُفْيَانَ الثَّوْرِيِّ ‏.‏ وَأَبُو الْيَقْظَانِ اسْمُهُ عُثْمَانُ بْنُ عُمَيْرٍ وَيُقَالُ ابْنُ قَيْسٍ ‏.‏\hadithno{2566}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{[Abdullah] Ibn 'Umar narrated that the Messenger of Allah (s.a.w) said:"Three shall be on dunes of musk" - it seems to me that he said:- "on the Day of Resurrection. The first and the last of peoples shall envy them: A man who calls to the five [prayers] every day and night; a man who leads a group of people and they are pleased with him, and a slave who fulfills the right of Allah and the right of his masters}}
\hadithdefcmd{tirmidhi}{2567}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ أَبِي بَكْرِ بْنِ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، يَرْفَعُهُ قَالَ ‏ "‏ ثَلاَثَةٌ يُحِبُّهُمُ اللَّهُ رَجُلٌ قَامَ مِنَ اللَّيْلِ يَتْلُو كِتَابَ اللَّهِ وَرَجُلٌ تَصَدَّقَ صَدَقَةً بِيَمِينِهِ يُخْفِيهَا أُرَاهُ قَالَ مِنْ شِمَالِهِ وَرَجُلٌ كَانَ فِي سَرِيَّةٍ فَانْهَزَمَ أَصْحَابُهُ فَاسْتَقْبَلَ الْعَدُوَّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَهُوَ غَيْرُ مَحْفُوظٍ ‏.‏ وَالصَّحِيحُ مَا رَوَى شُعْبَةُ وَغَيْرُهُ عَنْ مَنْصُورٍ عَنْ رِبْعِيِّ بْنِ حِرَاشٍ عَنْ زَيْدِ بْنِ ظَبْيَانَ عَنْ أَبِي ذَرٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَأَبُو بَكْرِ بْنُ عَيَّاشٍ كَثِيرُ الْغَلَطِ ‏.‏\hadithno{2567}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin Mas'ud narrated a Marfu' narration:"There are three whom Allah, the Mighty and Glorious, loves: A man who stood at night reciting the Book of Allah; a man who spent in charity with his right hand, concealing it"- it seems to me he said "from his left hand"- "and a man who was in a small expedition while his companions were decimated, yet he faced enemy." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2568}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورِ بْنِ الْمُعْتَمِرِ، قَالَ سَمِعْتُ رِبْعِيَّ بْنَ حِرَاشٍ، يُحَدِّثُ عَنْ زَيْدِ بْنِ ظَبْيَانَ، يَرْفَعُهُ إِلَى أَبِي ذَرٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ ثَلاَثَةٌ يُحِبُّهُمُ اللَّهُ وَثَلاَثَةٌ يَبْغَضُهُمُ اللَّهُ فَأَمَّا الَّذِينَ يُحِبُّهُمُ اللَّهُ فَرَجُلٌ أَتَى قَوْمًا فَسَأَلَهُمْ بِاللَّهِ وَلَمْ يَسْأَلْهُمْ بِقَرَابَةٍ بَيْنَهُ وَبَيْنَهُمْ فَمَنَعُوهُ فَتَخَلَّفَ رَجُلٌ بِأَعْقَابِهِمْ فَأَعْطَاهُ سِرًّا لاَ يَعْلَمُ بِعَطِيَّتِهِ إِلاَّ اللَّهُ وَالَّذِي أَعْطَاهُ وَقَوْمٌ سَارُوا لَيْلَتَهُمْ حَتَّى إِذَا كَانَ النَّوْمُ أَحَبَّ إِلَيْهِمْ مِمَّا يُعْدَلُ بِهِ نَزَلُوا فَوَضَعُوا رُءُوسَهُمْ فَقَامَ أَحَدُهُمْ يَتَمَلَّقُنِي وَيَتْلُو آيَاتِي وَرَجُلٌ كَانَ فِي سَرِيَّةٍ فَلَقِيَ الْعَدُوَّ فَهُزِمُوا وَأَقْبَلَ بِصَدْرِهِ حَتَّى يُقْتَلَ أَوْ يُفْتَحَ لَهُ ‏.‏ وَالثَّلاَثَةُ الَّذِينَ يَبْغَضُهُمُ اللَّهُ الشَّيْخُ الزَّانِي وَالْفَقِيرُ الْمُخْتَالُ وَالْغَنِيُّ الظَّلُومُ ‏"‏ ‏.‏ حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، عَنْ شُعْبَةَ، نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَهَكَذَا رَوَى شَيْبَانُ، عَنْ مَنْصُورٍ، نَحْوَ هَذَا وَهَذَا أَصَحُّ مِنْ حَدِيثِ أَبِي بَكْرِ بْنِ عَيَّاشٍ ‏.‏\hadithno{2568}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Dharr narrated that the Prophet(s.a.w) said:"There are three whom Allah loves and three whom Allah hates. As for those whom Allah loves: Then a man who came to a people and asked them by Allah, and he did not ask them due to any relation between him and them, but they did not give him. So a man stayed behind them and gave him secretly, none knew about what he gave except Allah and the one he gave. And, a group of people who traveled the night until when sleep became more beloved to them than all the things that equal it and they lay their heads down, but a man stoop up humbling himself to Me and reciting My Ayat. And a man who was in a small expedition and met the enemy and they were vanquished, yet he faced them until he was killed or victory was granted to him. And the three whom Allah hates are, the old man who commits adultery, the arrogant poor man, and the oppressive rich man." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2569}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ جَدِّهِ، حَفْصِ بْنِ عَاصِمٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُوشِكُ الْفُرَاتُ يَحْسِرُ عَنْ كَنْزٍ مِنْ ذَهَبٍ فَمَنْ حَضَرَهُ فَلاَ يَأْخُذْ مِنْهُ شَيْئًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2569}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"The Euphrates shall soon uncover a treasure of gold, so whoever witnesses it, let him not take anything from it}}
\hadithdefcmd{tirmidhi}{2570}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ إِلاَّ أَنَّهُ قَالَ ‏ "‏ يَحْسِرُ عَنْ جَبَلٍ مِنْ ذَهَبٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2570}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Prophet(s.a.w) said similar to it, except that he said,:"uncover a pot of gold}}
\hadithdefcmd{tirmidhi}{2571}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا الْجُرَيْرِيُّ، عَنْ حَكِيمِ بْنِ مُعَاوِيَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ فِي الْجَنَّةِ بَحْرَ الْمَاءِ وَبَحْرَ الْعَسَلِ وَبَحْرَ اللَّبَنِ وَبَحْرَ الْخَمْرِ ثُمَّ تُشَقَّقُ الأَنْهَارُ بَعْدُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَحَكِيمُ بْنُ مُعَاوِيَةَ هُوَ وَالِدُ بَهْزِ بْنِ حَكِيمٍ وَالْجُرَيْرِيُّ يُكْنَى أَبَا مَسْعُودٍ وَاسْمُهُ سَعِيدُ بْنُ إِيَاسٍ ‏.‏\hadithno{2571}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Hakim bin Mu'awiyah narrated from his father, that the Prophet (s.a.w) said:"Indeed in Paradise there is a sea of water, and a sea of honey,and a sea of milk, and a sea of wine, then the rivers shall split off afterwards}}
\hadithdefcmd{tirmidhi}{2572}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ بُرَيْدِ بْنِ أَبِي مَرْيَمَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَأَلَ اللَّهَ الْجَنَّةَ ثَلاَثَ مَرَّاتٍ قَالَتِ الْجَنَّةُ اللَّهُمَّ أَدْخِلْهُ الْجَنَّةَ ‏.‏ وَمَنِ اسْتَجَارَ مِنَ النَّارِ ثَلاَثَ مَرَّاتٍ قَالَتِ النَّارُ اللَّهُمَّ أَجِرْهُ مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ هَكَذَا رَوَى يُونُسُ بْنُ أَبِي إِسْحَاقَ عَنْ أَبِي إِسْحَاقَ هَذَا الْحَدِيثَ عَنْ بُرَيْدِ بْنِ أَبِي مَرْيَمَ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَقَدْ رُوِيَ عَنْ أَبِي إِسْحَاقَ عَنْ بُرَيْدِ بْنِ أَبِي مَرْيَمَ عَنْ أَنَسِ بْنِ مَالِكٍ مَوْقُوفًا أَيْضًا ‏.‏\hadithno{2572}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah (s.a.w) said:"Whoever asks Allah (s.w.t) Paradise three times, Paradise says: 'O Allah, admit him into Paradise', and whoever seeks refuge from the Fire three times, the Fire says: 'O Allah, save him from the Fire.'" Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2735}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا مُوسَى بْنُ مَسْعُودٍ أَبُو حُذَيْفَةَ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ عِكْرِمَةَ بْنِ أَبِي جَهْلٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ جِئْتُهُ ‏ "‏ مَرْحَبًا بِالرَّاكِبِ الْمُهَاجِرِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ بُرَيْدَةَ وَابْنِ عَبَّاسٍ وَأَبِي جُحَيْفَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لَيْسَ إِسْنَادُهُ بِصَحِيحٍ لاَ نَعْرِفُهُ مِثْلَ هَذَا إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ مُوسَى بْنِ مَسْعُودٍ عَنْ سُفْيَانَ ‏.‏ وَمُوسَى بْنُ مَسْعُودٍ ضَعِيفٌ فِي الْحَدِيثِ ‏.‏ وَرَوَى هَذَا الْحَدِيثَ عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ عَنْ سُفْيَانَ عَنْ أَبِي إِسْحَاقَ مُرْسَلاً وَلَمْ يَذْكُرْ فِيهِ عَنْ مُصْعَبِ بْنِ سَعْدٍ ‏.‏ وَهَذَا أَصَحُّ ‏.‏ قَالَ سَمِعْتُ مُحَمَّدَ بْنَ بَشَّارٍ يَقُولُ مُوسَى بْنُ مَسْعُودٍ ضَعِيفٌ فِي الْحَدِيثِ ‏.‏ قَالَ مُحَمَّدُ بْنُ بَشَّارٍ وَكَتَبْتُ كَثِيرًا عَنْ مُوسَى بْنِ مَسْعُودٍ ثُمَّ تَرَكْتُهُ ‏.‏ كَمُلَ كِتَابُ الاِسْتِئْذَانِ وَيَتْلُوهُ كِتَابُ الأَدَبِ\hadithno{2735}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ikrimah bin Abi Jahl:"The day that I came to him, the Messenger of Allah (ﷺ) said: "Welcome to the riding emigrant.'" There are narrations on this topic from Buraidah, Ibn 'Abbas, and Abu Juhaifah}}
